classdef Box2D < svui.app.geom2d.Geometry2D
%ELLIPSE2D An ellipse, defined by center, semi-axes length and orientation
%
%   Class Box2D
%
%   Example
%   Box2D
%
%   See also
%
%
% ------
% Author: David Legland
% e-mail: david.legland@grignon.inra.fr
% Created: 2013-10-18,    using Matlab 7.9.0.529 (R2009b)
% Copyright 2013 INRA - Cepia Software Platform.


%% Properties
properties
    data;
    
end % end properties


%% Constructor
methods
    function this = Box2D(varargin)
    % Constructor for Box2D class
    
        if ~isempty(varargin)
            this.data = varargin{1};
        else
            this.data = [0 1 0 1];
        end
    end

end % end constructors


%% Methods
methods
    function box = boundingBox(this)
        % returns the bounding box of this shape
        box = this.data;
    end
    
    function varargout = draw(this, varargin)
        % draw the current geometry, eventually specifying the style
        
        h = drawBox(this.data);
        if nargin > 1
            var1 = varargin{1};
            if isa(var1, 'svui.app.Style')
                applyStyle(var1, h);
            end
        end
        
        if nargout > 0
            varargout = {h};
        end
    end
    
    function res = scale(this, varargin)
        % returns a scaled version of this geometry
        factor = varargin{1};
        res = svui.app.geom2d.Box2D(this.data * factor);
    end
    
    function res = translate(this, varargin)
        % returns a translated version of this geometry
        shift = varargin{1};
        data2 = this.data + shift(1, [1 1 2 2]);
        res = svui.app.geom2d.Box2D(data2);
    end
    
end % end methods

end % end classdef

