classdef Ellipse2D < svui.app.geom2d.Geometry2D
%ELLIPSE2D An ellipse, defined by center, semi-axes length and orientation
%
%   Class Ellipse2D
%
%   Example
%   Ellipse2D
%
%   See also
%
%
% ------
% Author: David Legland
% e-mail: david.legland@grignon.inra.fr
% Created: 2013-10-18,    using Matlab 7.9.0.529 (R2009b)
% Copyright 2013 INRA - Cepia Software Platform.


%% Properties
properties
    % 
    data;
    
end % end properties


%% Constructor
methods
    function this = Ellipse2D(varargin)
    % Constructor for Ellipse2D class
    
        if ~isempty(varargin)
            this.data = varargin{1};
        else
            this.data = [0 0 1 1 0];
        end
    end

end % end constructors


%% Methods
methods
    function box = boundingBox(this)
        % returns the bounding box of this shape
        theta = deg2rad(this.data(5));
        cot = cos(theta);
        sit = sin(theta);
		xm = hypot(this.data(3) * cot, this.data(4) * sit);
		ym = hypot(this.data(3) * sit, this.data(4) * cot);
        xc = this.data(1);
        yc = this.data(2);
		box = [xc - xm, xc + xm, yc - ym, yc + ym];
    end
    
    function varargout = draw(this, varargin)
        % draw the current geometry, eventually specifying the style
        
        h = drawEllipse(this.data);
        if nargin > 1
            var1 = varargin{1};
            if isa(var1, 'svui.app.Style')
                applyStyle(var1, h);
            end
        end
        
        if nargout > 0
            varargout = {h};
        end
    end
    
    function res = scale(this, varargin)
        % returns a scaled version of this geometry
        factor = varargin{1};
        res = svui.app.geom2d.Ellipse2D(this.data .* [1 1 factor factor 1]);
    end
    
    function res = translate(this, varargin)
        % returns a translated version of this geometry
        shift = varargin{1};
        center2 = this.data(1:2) + shift;
        res = svui.app.geom2d.Ellipse2D([center2 this.data(3:5)]);
    end
    
end % end methods

end % end classdef

