classdef Polyline2D < svui.app.geom2d.Geometry2D
%Polyline2D An open polyline (line string) in the plane
%
%   Class Polyline2D
%
%   Example
%   Polyline2D
%
%   See also
%
%
% ------
% Author: David Legland
% e-mail: david.legland@grignon.inra.fr
% Created: 2013-10-18,    using Matlab 7.9.0.529 (R2009b)
% Copyright 2013 INRA - Cepia Software Platform.


%% Properties
properties
    % the set of vertices, given as a N-by-2 array of coordinates
    vertices;
    
end % end properties


%% Constructor
methods
    function this = Polyline2D(varargin)
    % Constructor for Polyline2D class
    
        if ~isempty(varargin)
            this.vertices = varargin{1};
        else
            this.vertices = [];
        end
    end

end % end constructors


%% Methods
methods
    function box = boundingBox(this)
        % returns the bounding box of this shape
        box = boundingBox(this.vertices);
    end
    
    function varargout = draw(this, varargin)
        % draw the current geometry, eventually specifying the style
        
        h = drawPolyline(this.vertices);
        if nargin > 1
            var1 = varargin{1};
            if isa(var1, 'svui.app.Style')
                applyStyle(var1, h);
            end
        end
        
        if nargout > 0
            varargout = {h};
        end
    end
    
    function res = scale(this, varargin)
        % returns a scaled version of this geometry
        factor = varargin{1};
        res = svui.app.geom2d.Polyline2D(this.vertices * factor);
    end
    
    function res = translate(this, varargin)
        % returns a translated version of this geometry
        shift = varargin{1};
        res = svui.app.geom2d.Polyline2D(bsxfun(@plus, this.vertices, shift));
    end
    
end % end methods

end % end classdef

