classdef Shape < handle
%SHAPE A graphical object that will be drawn with given style
%
%   output = Shape(input)
%
%   Example
%   Shape
%
%   See also
%
%
% ------
% Author: David Legland
% e-mail: david.legland@grignon.inra.fr
% Created: 2011-12-12,    using Matlab 7.9.0.529 (R2009b)
% Copyright 2011 INRA - Cepia Software Platform.

properties
    % a name for uniquely identifying this shape
    name;
    
%     % a string that describes what is this shape
%     type;
%     
%     % data needed to draw the shape. Either coordinates of vertices, or
%     % synthetic parameter representing the shape
%     data;
    
    geometry;
    
    % drawing style, as a cell array of options compatible with plot.
    style;
end

methods
    function this = Shape(varargin)
        % Constructor for a new Shape
        %
        %   shape = Shape();
        %   shape = Shape(GEOM);
        %   shape = Shape(GEOM, STYLE);
        
        this = this@handle;
        
        % parse the geometry of the shape
        if nargin > 0
            if isa(varargin{1}, 'svui.app.Geometry');
                this.geometry = varargin{1};
                varargin(1) = [];
                
            elseif isnumeric(varargin{1})
                data = varargin{1};
                
                % choose geometry type
                type = 'polygon';
                if nargin > 1 && ischar(varargin{2})
                    type = varargin{2};
                    varargin(2) = [];
                end
                
                % create geometry from data and type string
                switch lower(type)
                    case 'polygon'
                        this.geometry = svui.app.geom2d.Polygon2D(data);
                    case 'polyline'
                        this.geometry = svui.app.geom2d.Polyline2D(data);
                    case 'pointset'
                        this.geometry = svui.app.geom2d.PointSet2D(data);
                    case 'box'
                        this.geometry = svui.app.geom2d.Box2D(data);
                    case 'ellipse'
                        this.geometry = svui.app.geom2d.Ellipse2D(data);
                    otherwise
                        error(['can not process geometry of type ' type]);
                end
                
                varargin(1) = [];
            end
        end
        
        % parse style if possible
        if ~isempty(varargin)
            if isa(varargin{1}, 'svui.app.Style');
                this.style = varargin{1};
            end
        end
            
    end
end

methods
    function translate(this, shift)
        this.geometry = translate(this.geometry, shift);
    end
    
    function scale(this, factor)
        this.geometry = factor(this.geometry, factor);
    end
end

methods
    function h = draw(this, varargin)
        
        if ~isempty(this.style)
            h = draw(this.geometry, this.style, varargin{:});
        else
            % Draw the shape with a set of param name-value pairs
            h = draw(this.geometry, varargin{:});
        end
    end
end

end