classdef ShapeViewerDoc < handle
%SHAPEVIEWERDOC  One-line description here, please.
%
%   output = ShapeViewerDoc(input)
%
%   Example
%   ShapeViewerDoc
%
%   See also
%
%
% ------
% Author: David Legland
% e-mail: david.legland@grignon.inra.fr
% Created: 2011-12-11,    using Matlab 7.9.0.529 (R2009b)
% Copyright 2011 INRA - Cepia Software Platform.


%% Properties
properties
    % the name of the doc
    name;
    
    % The set of shapes stored in the document.
    % Stored as an array of svui.app.Shape instances
    shapes = [];
    
    % The bounding box of the current view. Stored as a 1-by-(2n) array.
    % Can be 2D or 3D
    viewBox = [];
    
    % a set of views attached to this doc. Can be image viewer, profiles...
    views = {};
    
    % a flag of modification
    modified = false;
    
    % the name of the unit for spatial coordinates
    userUnit = '';
    
    % boolean flag indicating if axis lines should be drawn
    axisLinesVisible = true;
    
    
end % end properties


%% Constructor
methods
    function this = ShapeViewerDoc()
    % Constructor for ShapeViewerDoc class

        this.name = 'no name';
    end

end % end constructors


%% Shapes management

methods
    function addShape(this, s)
        % add a given shape to this doc
        this.shapes = [this.shapes s];
    end
    
    function removeShape(this, s)
        % remove a given shape from this doc
        ind = [];
        for i = 1:length(this.shapes)
            if this.shapes(i) == s
                ind = i;
                break;
            end
        end
        if isempty(ind)
            disp('could not find shape to remove');
            return;
        end
        this.shapes(ind) = [];
    end
    
    function shapes = getShapes(this)
        % return a cell array containing the shapes in this doc
        shapes = this.shapes;
    end
    
    function clearShapes(this)
        % return a cell array containing the shapes in this doc
        this.shapes = {};
    end
    
end


%% Views management
methods
    function addView(this, v)
        this.views = [this.views {v}];
    end
    
    function removeView(this, v)
        ind = -1;
        for i = 1:length(this.views)
            if this.views{i} == v
                ind = i;
                break;
            end
        end
        
        if ind == -1
            error('could not find the view');
        end
        
        this.views(ind) = [];
    end
    
    function v = getViews(this)
        v = this.views;
    end
    
end % end methods

methods
    function box = boundingBox(this)
        % Computes bounding box of the current document
        
        xmin = inf;
        ymin = inf;
        xmax = -inf;
        ymax = -inf;
        for i = 1:length(this.shapes)
            shape = this.shapes(i);
            box = boundingBox(shape.geometry);
            xmin = min(xmin, box(1));
            xmax = max(xmax, box(2));
            ymin = min(ymin, box(3));
            ymax = max(ymax, box(4));
        end
        box = [xmin xmax ymin ymax];
    end
    
%     function box = shapeBounds(this, shape) %#ok<MANU>
%         % Compute the bounding box of the input shape
%         % (used for computing the document bounding box)
%         
%         switch(shape.type)
%             case 'polygon'
%                 box = boundingBox(shape.data);
%             case 'circle'
%                 xc = shape.data(1);
%                 yc = shape.data(2);
%                 r  = shape.data(3);
%                 box = [xc-r xc+r yc-r yc+r];
%             otherwise
%                 warning('ShapeViewer:UnknowShapeType', ...
%                     ['unknown shape type: ' shape.type]);
%         end
%     end
end


end % end classdef

