classdef Style < handle
%STYLE Defines the drawing style of 2D/3D geometries
%
%   Class Style
%
%   Example
%   Style
%
%   See also
%
%
% ------
% Author: David Legland
% e-mail: david.legland@grignon.inra.fr
% Created: 2013-10-18,    using Matlab 7.9.0.529 (R2009b)
% Copyright 2013 INRA - Cepia Software Platform.


%% Properties
properties
    color       = 'b';
    
    lineWidth   = .5;
    lineStyle   = '-'
    
end % end properties


%% Constructor
methods
    function this = Style(varargin)
        % Constructor for Style class
        
        this = this@handle;
        
        % parse the input style
        if nargin > 0
            if isa(varargin{1}, 'svui.app.Style');
                % Copy constructor: copy each property
                that = varargin{1};
                this.color      = that.color;
                this.lineWidth  = that.lineWidth;
                this.lineStyle  = that.lineStyle;
                varargin(1) = [];
            end
        end

        % parse a collection of name-value parameter pairs
        while length(varargin) >= 2
            name = varargin{1};
            switch lower(name)
                case 'color'
                    this.color = varargin{2};
                case 'linewidth'
                    this.lineWidth = varargin{2};
                case 'linestyle'
                    this.lineStyle = varargin{2};
                otherwise
                    error(['Can not parse style parameter: ' name]);
            end
            varargin(1:2) = [];
        end
    end

end % end constructors


%% Methods
methods
    function applyStyle(this, handle)
        set(handle, 'color', this.color);
        set(handle, 'lineWidth', this.lineWidth);
        set(handle, 'lineStyle', this.lineStyle);
        
    end
end % end methods

end % end classdef

