classdef AddShapeInertiaEllipseAction < svui.gui.ShapeViewerAction
%ADDSHAPEINERTIAELLIPSEACTION add the inertia ellipse of selected shape to doc
%
%   Class AddShapeInertiaEllipseAction
%
%   Example
%   AddShapeInertiaEllipseAction
%
%   See also
%
%
% ------
% Author: David Legland
% e-mail: david.legland@grignon.inra.fr
% Created: 2012-04-13,    using Matlab 7.9.0.529 (R2009b)
% Copyright 2012 INRA - Cepia Software Platform.


%% Properties
properties
end % end properties


%% Constructor
methods
    function this = AddShapeInertiaEllipseAction(viewer, varargin)
    % Constructor for AddShapeInertiaEllipseAction class

        % calls the parent constructor
        this = this@svui.gui.ShapeViewerAction(viewer, 'addBoundingBox');
    end

end % end constructors


%% Methods
methods
    function actionPerformed(this, src, event) %#ok<INUSD>
        disp('add inertia ellipse');
        
        % get handle to parent viewer, and selected shapes
        viewer = this.viewer;
        shapes = viewer.selectedShapes;
        
        % basic input checks
        if isempty(shapes)
            return;
        end
        if length(shapes) > 1
            errordlg('Can not operate on several shapes', 'Selection Error', 'modal');
            return;
        end
        
        shape = shapes(1);
 
        % compute inertia ellipsoid from vertices
        tokens = regexp(class(shape.geometry), '\.', 'split');
        shapeClass = tokens{end};
        if ismember(shapeClass, {'Polygon2D', 'Polyline2D', 'PointSet2D'})
            elli = inertiaEllipse(shape.geometry.vertices);
        else
            error(['Wrong data type: ' class(shape.geometry)]);
        end

        % create the shape corresponding to the box
        shape = svui.app.Shape(svui.app.geom2d.Ellipse2D(elli), ...
            {'linewidth', 1, 'color', 'm'});
        
        addShape(this.viewer.doc, shape);
        
        updateDisplay(viewer);
        
    end
end % end methods

end % end classdef

