classdef AddShapeOrientedBoxAction < svui.gui.ShapeViewerAction
%ADDSHAPEBOUNDINGBOXACTION add the bounding box of selected shape to doc
%
%   Class AddShapeOrientedBoxAction
%
%   Example
%   AddShapeOrientedBoxAction
%
%   See also
%
%
% ------
% Author: David Legland
% e-mail: david.legland@grignon.inra.fr
% Created: 2012-04-13,    using Matlab 7.9.0.529 (R2009b)
% Copyright 2012 INRA - Cepia Software Platform.


%% Properties
properties
end % end properties


%% Constructor
methods
    function this = AddShapeOrientedBoxAction(viewer, varargin)
    % Constructor for AddShapeOrientedBoxAction class

        % calls the parent constructor
        this = this@svui.gui.ShapeViewerAction(viewer, 'addBoundingBox');
    end

end % end constructors


%% Methods
methods
    function actionPerformed(this, src, event) %#ok<INUSD>
        disp('add oriented box');
        
        % get handle to parent viewer, and selected shapes
        viewer = this.viewer;
        shapes = viewer.selectedShapes;
        
        % basic input checks
        if isempty(shapes)
            return;
        end
        if length(shapes) > 1
            errordlg('Can not operate on several shapes', 'Selection Error', 'modal');
            return;
        end
        
        shape = shapes(1);
     
        % compute bounding box
        tokens = regexp(class(shape.geometry), '\.', 'split');
        shapeClass = tokens{end};
        if ismember(shapeClass, {'Polygon2D', 'Polyline2D', 'PointSet2D'})
            box = orientedBox(shape.geometry.vertices);
        else
            error(['Wrong data type: ' class(shape.geometry)]);
        end
 
        % create the shape corresponding to the box
        poly = orientedBoxToPolygon(box);
        shape = svui.app.Shape(svui.app.geom2d.Polygon2D(poly), ...
            svui.app.Style('linewidth', 1, 'color', 'k'));
        
        addShape(this.viewer.doc, shape);
        
        updateDisplay(viewer);
        
    end
end % end methods

end % end classdef

