classdef DisplaySelectionInfoAction < svui.gui.ShapeViewerAction
%DISPLAYSELECTIONINFOACTION  Display info on selected shapes
%
%   Class DisplaySelectionInfoAction
%
%   Example
%   DisplaySelectionInfoAction
%
%   See also
%
%
% ------
% Author: David Legland
% e-mail: david.legland@grignon.inra.fr
% Created: 2012-06-18,    using Matlab 7.9.0.529 (R2009b)
% Copyright 2012 INRA - Cepia Software Platform.


%% Properties
properties
end % end properties


%% Constructor
methods
    function this = DisplaySelectionInfoAction(viewer, varargin)
    % Constructor for DisplaySelectionInfoAction class

        % calls the parent constructor
        this = this@svui.gui.ShapeViewerAction(viewer, 'displaySelectionInfo');
    end

end % end constructors


%% Methods
methods
    function actionPerformed(this, src, event) %#ok<INUSD>
        disp('display selected shapes info');
        
        % get handle to parent figure, and current doc
        viewer = this.viewer;
        
        % get selection tool
        tool = viewer.currentTool;
        if isempty(tool)
            return;
        end
        if ~isa(tool, 'svui.gui.tools.SelectionTool')
            return;
        end
        
        % extract selected shapes
        handles = tool.selectedHandles;
        for i = 1:length(handles)
            shape = get(handles(i), 'UserData');
            
            type = shape.type;
            switch lower(type)
                case 'polygon'
                    disp('Polygon');
                    fprintf('  %d vertices\n', size(shape.data, 1));
                    fprintf('  centroid = (%f, %f)\n', polygonCentroid(shape.data));
                    fprintf('  perimeter = %f\n', polygonLength(shape.data));
                    fprintf('  area = %f\n', polygonArea(shape.data));
                    
                case 'pointset'
                    disp('Point Set');
                    fprintf('  %d vertices\n', size(shape.data, 1));

                case 'box'
                    disp('Bounding Box');
                    data = shape.data;
                    fprintf('  xmin = %g\n', data(1));
                    fprintf('  xmax = %g\n', data(2));
                    fprintf('  ymin = %g\n', data(3));
                    fprintf('  ymax = %g\n', data(4));

                otherwise
                    error(['unknown shape type: ' shape.type]);
            end
        end
        
    end
    
end % end methods

end % end classdef

