classdef OpenPolygonInTableAction < svui.gui.ShapeViewerAction
%OpenPolygonInTableAction  Open a polygon whose coords are stored in a table file 
%
%   Class OpenPolygonInTableAction
%
%   Example
%   OpenPolygonInTableAction
%
%   See also
%
%
% ------
% Author: David Legland
% e-mail: david.legland@grignon.inra.fr
% Created: 2012-01-29,    using Matlab 7.9.0.529 (R2009b)
% Copyright 2012 INRA - Cepia Software Platform.


%% Properties
properties
end % end properties


%% Constructor
methods
    function this = OpenPolygonInTableAction(viewer, varargin)
    % Constructor for OpenPolygonInTableAction class

        % calls the parent constructor
        this = this@svui.gui.ShapeViewerAction(viewer, 'openImage');
    end

end % end constructors


%% Methods
methods
    function actionPerformed(this, src, event) %#ok<INUSD>
        disp('Open a polygon in table');
        
        % get handle to parent figure, and current doc
        viewer = this.viewer;
        doc = viewer.doc;
        
        [fileName, pathName] = uigetfile( ...
            {
            '*.txt',                    'Text files (*.txt)'; ...
            '*.*',                      'All Files (*.*)'}, ...
            'Choose data table containing polygon vertices:', ...
            viewer.lastOpenPath, ...
            'MultiSelect', 'on');
        
        if isequal(fileName,0) || isequal(pathName,0)
            return;
        end

        % save load path
        viewer.lastOpenPath = pathName;
        
        if ischar(fileName)
            importPolygon(fileName, pathName);
        elseif iscell(fileName)
            for i = 1:length(fileName)
                importPolygon(fileName{i}, pathName);
            end
        end
        
        updateDisplay(viewer);
        
        function importPolygon(fileName, pathName)
            % Inner function to read a polygon and add it the the document
            tab = Table.read(fullfile(pathName, fileName));
            
            % create polygon
            poly    = tab.data;
            shape   = svui.app.Shape(poly, 'polygon');
            
            [path name] = fileparts(fileName); %#ok<ASGLU>
            shape.name = name;
            
            addShape(doc, shape);
        end
        
    end
end % end methods

end % end classdef

