classdef ScaleShapeAction < svui.gui.ShapeViewerAction
%SCALESHAPEACTION  Scale the selected shape by a given factor
%
%   Class ScaleShapeAction
%
%   Example
%   ScaleShapeAction
%
%   See also
%
%
% ------
% Author: David Legland
% e-mail: david.legland@grignon.inra.fr
% Created: 2012-06-18,    using Matlab 7.9.0.529 (R2009b)
% Copyright 2012 INRA - Cepia Software Platform.


%% Properties
properties
end % end properties


%% Constructor
methods
    function this = ScaleShapeAction(viewer, varargin)
    % Constructor for ScaleShapeAction class

        % calls the parent constructor
        this = this@svui.gui.ShapeViewerAction(viewer, 'scaleShape');
    end

end % end constructors


%% Methods
methods
    function actionPerformed(this, src, event) %#ok<INUSD>
        disp('display selected shapes info');
        
        % get handle to parent figure, and current doc
        viewer = this.viewer;
        
        % get selection tool
        tool = viewer.currentTool;
        if isempty(tool)
            return;
        end
        if ~isa(tool, 'svui.gui.tools.SelectionTool')
            return;
        end
        
        % input scaling factor
        answer = inputdlg(...
            'Input Scale Factor:', ...
            'Scale Shape', ...
            1, {'1'});
        if isempty(answer)
            return;
        end
        scaleFactor = str2double(answer);
        if isnan(scaleFactor)
            return;
        end
        
        % transform each selected shape
        shapes = viewer.selectedShapes;
        for i = 1:length(shapes)
            scale(shapes(i), scaleFactor);
        end

        
        updateDisplay(viewer);
    end
    
end % end methods

end % end classdef

