classdef SetDocumentViewBoxAction < svui.gui.ShapeViewerAction
%SetDocumentViewBoxAction add a set of random points to current doc
%
%   Class SetDocumentViewBoxAction
%
%   Example
%   SetDocumentViewBoxAction
%
%   See also
%
%
% ------
% Author: David Legland
% e-mail: david.legland@grignon.inra.fr
% Created: 2012-01-29,    using Matlab 7.9.0.529 (R2009b)
% Copyright 2012 INRA - Cepia Software Platform.


%% Properties
properties
end % end properties


%% Constructor
methods
    function this = SetDocumentViewBoxAction(viewer, varargin)
    % Constructor for SetDocumentViewBoxAction class

        % calls the parent constructor
        this = this@svui.gui.ShapeViewerAction(viewer, 'setDocumentViewBox');
    end

end % end constructors


%% Methods
methods
    function actionPerformed(this, src, event) %#ok<INUSD>
        
        % get handle to parent figure, and current doc
        viewer = this.viewer;
        doc = viewer.doc;
        box = doc.viewBox;
        if isempty(box)
            ax = viewer.handles.mainAxis;
            box = [get(ax, 'xlim') get(ax, 'ylim')];
        end
        
        answer = inputdlg(...
            {'X Min:', 'X Max:', 'Y Min:', 'Y Max:'}, ...
            'Set Bounding Box', ...
            1, ...
            cellstr(num2str(box'))');
        if isempty(answer)
            return;
        end
        
        xmin = str2double(answer{1});
        xmax = str2double(answer{2});
        ymin = str2double(answer{3});
        ymax = str2double(answer{4});
        box = [xmin xmax ymin ymax];
        if any(isnan(box))
            return;
        end
        
        doc.viewBox = box;
        
        updateDisplay(viewer);
    end
end % end methods

end % end classdef

