classdef SetSelectedShapeStyleAction < svui.gui.ShapeViewerAction
%SCALESHAPEACTION  Scale the selected shape by a given factor
%
%   Class SetSelectedShapeStyleAction
%
%   Example
%   SetSelectedShapeStyleAction
%
%   See also
%
%
% ------
% Author: David Legland
% e-mail: david.legland@grignon.inra.fr
% Created: 2012-06-18,    using Matlab 7.9.0.529 (R2009b)
% Copyright 2012 INRA - Cepia Software Platform.


%% Properties
properties
end % end properties


%% Constructor
methods
    function this = SetSelectedShapeStyleAction(viewer, varargin)
    % Constructor for SetSelectedShapeStyleAction class

        % calls the parent constructor
        this = this@svui.gui.ShapeViewerAction(viewer, 'setShapeStyle');
    end

end % end constructors


%% Methods
methods
    function actionPerformed(this, src, event) %#ok<INUSD>
        disp('set shape style');
        
        % get handle to parent figure, and current doc
        viewer = this.viewer;
        
        % get selection tool
        tool = viewer.currentTool;
        if isempty(tool)
            return;
        end
        if ~isa(tool, 'svui.gui.tools.SelectionTool')
            return;
        end
        
        % input scaling factor
        answer = inputdlg(...
            {'Color:', 'Line Width', 'LineStyle'}, ...
            'Set Shape Style', ...
            1, {'blue', '.5', '-'});
        if isempty(answer)
            return;
        end

        colorNames = {'red', 'green', 'blue', 'cyan', 'magenta', 'yellow', 'black'};
        colors = [1 0 0;0 1 0;0 0 1;0 1 1;1 0 1;1 1 0;0 0 0];
        
        % parse user answers
        
        colorIndex = strmatch(answer{1}, colorNames);
        if isempty(colorIndex)
            errordlg(...
                ['Could not parse color name: ' answer{1}], ...
                'Parse Error', 'modal'); 
            return;
        end
        newColor = colors(colorIndex, :);
        
        newWidth = str2double(answer{2});
        
        newLineStyle = answer{3};
        
        
        % transform each selected shape
        shapes = viewer.selectedShapes;
        for i = 1:length(shapes)
            shape = shapes(i);
            style = shape.style;
            if isempty(style)
                style = svui.app.Style();
            end
            
            style.color     = newColor;
            style.lineWidth = newWidth;
            style.lineStyle = newLineStyle;
            
            shape.style = style;
        end
        
        updateDisplay(viewer);
    end
    
end % end methods

end % end classdef

