classdef SimplifyPolygonAction < svui.gui.ShapeViewerAction
%ADDSHAPEBOUNDINGBOXACTION add the convex hull of selected shape to doc
%
%   Class SimplifyPolygonAction
%
%   Example
%   SimplifyPolygonAction
%
%   See also
%
%
% ------
% Author: David Legland
% e-mail: david.legland@grignon.inra.fr
% Created: 2012-04-13,    using Matlab 7.9.0.529 (R2009b)
% Copyright 2012 INRA - Cepia Software Platform.


%% Properties
properties
end % end properties


%% Constructor
methods
    function this = SimplifyPolygonAction(viewer, varargin)
    % Constructor for SimplifyPolygonAction class

        % calls the parent constructor
        this = this@svui.gui.ShapeViewerAction(viewer, 'simplifyPolygon');
    end

end % end constructors


%% Methods
methods
    function actionPerformed(this, src, event) %#ok<INUSD>
        disp('simplifyPolygon');
        
        % get handle to parent viewer, and selected shapes
        viewer = this.viewer;
        shapes = viewer.selectedShapes;
        
        % basic input checks
        if isempty(shapes)
            return;
        end
        if length(shapes) > 1
            errordlg('Can not operate on several shapes', 'Selection Error', 'modal');
            return;
        end
        
        shape = shapes(1);

        % check type of input shape
        tokens = regexp(class(shape.geometry), '\.', 'split');
        shapeClass = tokens{end};
        if ~ismember(shapeClass, {'Polygon2D', 'Polyline2D'})
            error('Can simplify only polygons or polylines');
        end

        % input the distance threshold
        answer = inputdlg(...
            'Input Distance Threshold:', ...
            'Douglas-Peucker Simplification', 1, ...
            {'.1'});
        if isempty(answer) 
            return;
        end
        
        delta = str2double(answer{1});
        if isnan(delta)
            return;
        end
        
        
        % simplify with douglas peucker
        if strcmpi(shapeClass, 'Polygon2D')
            data2 = simplifyPolygon(shape.geometry.vertices, delta);
            shape = svui.app.Shape(data2, 'polygon');

        elseif strcmpi(shapeClass, 'Polyline2D')
            data2 = simplifyPolyline(shape.geometry.vertices, delta);
            shape = svui.app.Shape(data2, 'polyline');
            
        end
        
        % create the shape corresponding to the simplified polygon
        addShape(this.viewer.doc, shape);
        updateDisplay(viewer);
        
    end
end % end methods

end % end classdef

