classdef ShapeViewerGUI < handle
%SHAPEVIEWERGUI Manager of the different windows
%
%   output = ShapeViewerGUI(input)
%
%   Example
%   ShapeViewerGUI
%
%   See also
%
%
% ------
% Author: David Legland
% e-mail: david.legland@grignon.inra.fr
% Created: 2011-12-11,    using Matlab 7.9.0.529 (R2009b)
% Copyright 2011 INRA - Cepia Software Platform.

%% Properties
properties
    % application
    app;
    
end 

%% Constructor
methods
    function this = ShapeViewerGUI(appli, varargin)
        % ShapeViewerGUI constructor
        %
        % IM = ShapeViewerGUI(APP)
        % where APP is an instance of ShapeViewerApp
        %
        
        this.app = appli;
        
    end % constructor 

end % construction function


%% General methods
methods
    function view = addNewDocument(this)
        % Create a new empty document, add to app, diplay it, and return it
        
        % creates new instance of ImageDoc
        doc = svui.app.ShapeViewerDoc();
        
        % add ImageDoc to the application
        addDocument(this.app, doc);
        
        % creates a display for the new image
        view = svui.gui.ShapeViewerMainFrame(this, doc);
        addView(doc, view);
        
    end
    
    function exit(this)
        % EXIT Close all viewers
           
        docList = getDocuments(this.app);
        for d = 1:length(docList)
            doc = docList{d};
            
            views = getViews(doc);
            for v = 1:length(views)
                view = views{v};
                removeView(doc, view);
                close(view);
            end
        
        end
    end
    
end % general methods

end % classdef
